Allow color diferent part of a string in a easy way

Example of usage:
colored("Hello everyone, <green>Happy</green> <lightred>New</lightred> <blue>Year</blue>")

<a href="https://github.com/alejup21/coloredtext.git">GitHub link project</a>